@@ -6,7 +6,7 @@ const WIDTH: u32 = 10;
 const HEIGHT: u32 = 10;
 
 fn main() -> NcResult<()> {
-    let mut nc = Nc::new()?;
+    let mut nc = Notcurses::new()?;
 
     if !nc.check_pixel_support()? {
         return Err(NcError::new_msg("Current terminal doesn't support pixels."));
@@ -23,7 +23,7 @@ fn main() -> NcResult<()> {
 
     let vframe = NcVisual::from_rgba(buffer.as_slice(), HEIGHT, WIDTH * 4, WIDTH)?;
     let voptions =
-        NcVisualOptions::without_plane(0, 0, 0, 0, HEIGHT, WIDTH, NCBLIT_PIXEL, 0, 0);
+        NcVisualOptions::without_plane(0, 0, 0, 0, 0, 0, NCBLIT_PIXEL, 0, 0);
 
     // vframe.inflate(1)?; // this works
 
@@ -33,5 +33,6 @@ fn main() -> NcResult<()> {
 
     rsleep![&mut nc, 2];
     vframe.destroy();
+    nc.stop()?;
     Ok(())
 }
